@@ -1,5 +1,5 @@
 # Metadata
-__version__ = "0.4.1"
+__version__ = "0.5.0"
 
 # Authentication scheme.
 from disruptive.authentication import Auth  # noqa
@@ -10,19 +10,19 @@ from disruptive.authentication import Auth  # noqa
 # each individual method with the same auth object.
 #
 # Available authentication methods:
-# auth = disruptive.Auth.serviceaccount(key_id, secret, email)
+# auth = disruptive.Auth.service_account(key_id, secret, email)
 #
 # Initialize package with unauthenticated object.
-default_auth = Auth({})
+default_auth = Auth.unauthenticated()
 
 # Resources.
 from disruptive.resources.device import Device  # noqa
-from disruptive.resources.dataconnector import DataConnector  # noqa
+from disruptive.resources.data_connector import DataConnector  # noqa
 from disruptive.resources.organization import Organization  # noqa
 from disruptive.resources.project import Project  # noqa
 from disruptive.resources.stream import Stream  # noqa
 from disruptive.resources.eventhistory import EventHistory  # noqa
-from disruptive.resources.serviceaccount import ServiceAccount  # noqa
+from disruptive.resources.service_account import ServiceAccount  # noqa
 from disruptive.resources.role import Role  # noqa
 from disruptive.resources.emulator import Emulator  # noqa
 
@@ -34,9 +34,8 @@ import disruptive.events as events  # noqa
 log_level = None
 
 # REST API base URLs of which all endpoints are an expansion.
-api_url = 'https://api.disruptive-technologies.com/v2'
-emulator_url = 'https://emulator.disruptive-technologies.com/v2'
-auth_url = 'https://identity.disruptive-technologies.com/oauth2/token'
+base_url = 'https://api.disruptive-technologies.com/v2'
+emulator_base_url = 'https://emulator.disruptive-technologies.com/v2'
 
 # If a request response contains an error for which a series of retries is
 # worth considering, these variable determine how long to wait without an
