@@ -6,6 +6,7 @@ import disruptive.logging as dtlog
 import disruptive.requests as dtrequests
 import disruptive.events.events as dtevents
 import disruptive.outputs as dtoutputs
+from disruptive.errors import TransferDeviceError, LabelUpdateError
 
 
 class Device(dtoutputs.OutputBase):
@@ -25,7 +26,7 @@ class Device(dtoutputs.OutputBase):
         Given device name if set through a label with key `name`.
         Otherwise None.
     device_type : str
-        Device type.
+        :ref:`Device type <device_type_constants>`.
     labels : dict
         Label keys and values.
     is_emulator : bool
@@ -103,13 +104,9 @@ class Device(dtoutputs.OutputBase):
             Unique ID of the target project.
             If not provided, a wildcard project will be used, resulting
             in a search for the device through all available projects.
-        auth: Auth, optional
-            Authorization object used to authenticate the REST API.
-            If provided it will be prioritized over global authentication.
-        request_timeout: int, optional
-            Seconds before giving up a request without an answer.
-        request_attempts: int, optional
-            Number of times a request is attempted before giving up.
+        **kwargs
+            Arbitrary keyword arguments.
+            See the :ref:`Configuration <configuration>` page.
 
         Returns
         -------
@@ -152,7 +149,7 @@ class Device(dtoutputs.OutputBase):
         device_ids : list[str], optional
             Specify devices by their unique IDs.
         device_types : list[str], optional
-            Specify devices by type.
+            Filter by :ref:`device types <device_type_constants>`.
         label_filters : dict[str, str], optional
             Specify devices by label keys and values (i.e. {"key": "value"}).
             If only a key is provided (i.e. {"key": ""}), all
@@ -161,13 +158,9 @@ class Device(dtoutputs.OutputBase):
             The field name you want to order the response by.
             Referred to using dot notation (i.e. "reported.temperature.value").
             Default order is ascending, but can be flipped by prefixing "-".
-        auth: Auth, optional
-            Authorization object used to authenticate the REST API.
-            If provided it will be prioritized over global authentication.
-        request_timeout: int, optional
-            Seconds before giving up a request without an answer.
-        request_attempts: int, optional
-            Number of times a request is attempted before giving up.
+        **kwargs
+            Arbitrary keyword arguments.
+            See the :ref:`Configuration <configuration>` page.
 
         Returns
         -------
@@ -215,7 +208,7 @@ class Device(dtoutputs.OutputBase):
                          source_project_id: str,
                          target_project_id: str,
                          **kwargs,
-                         ) -> None:
+                         ) -> list[TransferDeviceError]:
         """
         Transfers all specified devices to the target project.
 
@@ -230,18 +223,20 @@ class Device(dtoutputs.OutputBase):
             Unique ID of the source project.
         target_project_id : str
             Unique ID of the target project.
-        auth: Auth, optional
-            Authorization object used to authenticate the REST API.
-            If provided it will be prioritized over global authentication.
-        request_timeout: int, optional
-            Seconds before giving up a request without an answer.
-        request_attempts: int, optional
-            Number of times a request is attempted before giving up.
+        **kwargs
+            Arbitrary keyword arguments.
+            See the :ref:`Configuration <configuration>` page.
+
+        Returns
+        -------
+        errors : list[TransferDeviceError]
+            A list that contains one error object for each device that
+            could not be successfully transferred.
 
         Examples
         --------
         >>> # Move a device from on project to another.
-        >>> disruptive.Device.transfer_devices(
+        >>> err = disruptive.Device.transfer_devices(
         ...     device_ids=[
         ...         '<DEVICE_ID_1>',
         ...         '<DEVICE_ID_2',
@@ -261,8 +256,8 @@ class Device(dtoutputs.OutputBase):
             "devices": devices
         }
 
-        # Sent POST request, but return nothing.
-        dtrequests.DTRequest.post(
+        # Sent POST request.
+        response = dtrequests.DTRequest.post(
             url='/projects/{}/devices:transfer'.format(
                 target_project_id
             ),
@@ -270,13 +265,16 @@ class Device(dtoutputs.OutputBase):
             **kwargs,
         )
 
+        # Return any transferErrors found in response.
+        return [TransferDeviceError(err) for err in response['transferErrors']]
+
     @staticmethod
     def set_label(device_id: str,
                   project_id: str,
                   key: str,
                   value: str,
                   **kwargs,
-                  ) -> None:
+                  ) -> list[LabelUpdateError]:
         """
         Set a label (key and value) for a single device.
 
@@ -292,13 +290,15 @@ class Device(dtoutputs.OutputBase):
             Label key to be added.
         value : str
             Label value to be added.
-        auth: Auth, optional
-            Authorization object used to authenticate the REST API.
-            If provided it will be prioritized over global authentication.
-        request_timeout: int, optional
-            Seconds before giving up a request without an answer.
-        request_attempts: int, optional
-            Number of times a request is attempted before giving up.
+        **kwargs
+            Arbitrary keyword arguments.
+            See the :ref:`Configuration <configuration>` page.
+
+        Returns
+        -------
+        errors : list[LabelUpdateError]
+            A list that contains one error object for each label that
+            could not be successfully updated.
 
         Examples
         --------
@@ -320,15 +320,18 @@ class Device(dtoutputs.OutputBase):
         body['devices'] = ['projects/' + project_id + '/devices/' + device_id]
         body['addLabels'] = {key: value}
 
-        # Sent POST request, but return nothing.
-        dtrequests.DTRequest.post(url, body=body, **kwargs)
+        # Sent POST request.
+        response = dtrequests.DTRequest.post(url, body=body, **kwargs)
+
+        # Return any batchErrors found in response.
+        return [LabelUpdateError(err) for err in response['batchErrors']]
 
     @staticmethod
     def remove_label(device_id: str,
                      project_id: str,
                      key: str,
                      **kwargs,
-                     ) -> None:
+                     ) -> list[LabelUpdateError]:
         """
         Remove a label (key and value) from a single device.
 
@@ -340,13 +343,15 @@ class Device(dtoutputs.OutputBase):
             Unique ID of the target project.
         key : str
             Key of the label to be removed.
-        auth: Auth, optional
-            Authorization object used to authenticate the REST API.
-            If provided it will be prioritized over global authentication.
-        request_timeout: int, optional
-            Seconds before giving up a request without an answer.
-        request_attempts: int, optional
-            Number of times a request is attempted before giving up.
+        **kwargs
+            Arbitrary keyword arguments.
+            See the :ref:`Configuration <configuration>` page.
+
+        Returns
+        -------
+        errors : list[LabelUpdateError]
+            A list that contains one error object for each label that
+            could not be successfully updated.
 
         Examples
         --------
@@ -367,8 +372,11 @@ class Device(dtoutputs.OutputBase):
         body['devices'] = ['projects/' + project_id + '/devices/' + device_id]
         body['removeLabels'] = [key]
 
-        # Sent POST request, but return nothing.
-        dtrequests.DTRequest.post(url, body=body, **kwargs)
+        # Sent POST request.
+        response = dtrequests.DTRequest.post(url, body=body, **kwargs)
+
+        # Return any batchErrors found in response.
+        return [LabelUpdateError(err) for err in response['batchErrors']]
 
     @staticmethod
     def batch_update_labels(device_ids: list[str],
@@ -376,13 +384,13 @@ class Device(dtoutputs.OutputBase):
                             set_labels: Optional[dict[str, str]] = None,
                             remove_labels: Optional[list[str]] = None,
                             **kwargs,
-                            ) -> None:
+                            ) -> list[LabelUpdateError]:
         """
         Add, update, or remove multiple labels (key and value)
         on multiple devices
 
-        Must provide either `add_labels` or `remove_labels`. If neither are
-        provided, a :ref:`BadRequest <badrequest>` error will be raised.
+        Must provide either `set_labels` or `remove_labels`. If neither are
+        provided, a :ref:`BadRequest <bad_request_error>` error will be raised.
 
         Parameters
         ----------
@@ -390,23 +398,25 @@ class Device(dtoutputs.OutputBase):
             List of unique IDs for the target devices.
         project_id : str
             Unique ID of target project.
-        add_labels : dict[str, str], optional
+        set_labels : dict[str, str], optional
             Key and value of labels to be added. If a label key
             already exists, the value is updated.
         remove_labels : list[str], optional
             Label keys to be removed.
-        auth: Auth, optional
-            Authorization object used to authenticate the REST API.
-            If provided it will be prioritized over global authentication.
-        request_timeout: int, optional
-            Seconds before giving up a request without an answer.
-        request_attempts: int, optional
-            Number of times a request is attempted before giving up.
+        **kwargs
+            Arbitrary keyword arguments.
+            See the :ref:`Configuration <configuration>` page.
+
+        Returns
+        -------
+        errors : list[LabelUpdateError]
+            A list that contains one error object for each label that
+            could not be successfully updated.
 
         Raises
         ------
         BadRequest
-            If neither `add_labels` nor `remove_labels` is provided.
+            If neither `set_labels` nor `remove_labels` is provided.
 
         Examples
         --------
@@ -417,7 +427,7 @@ class Device(dtoutputs.OutputBase):
         ...         '<DEVICE_ID_2>',
         ...     ],
         ...     project_id='<PROJECT_ID>',
-        ...     add_labels={
+        ...     set_labels={
         ...         'new-label-1': 'value-1',
         ...         'new-label-2': 'value-2',
         ...         'new-label-3': 'value-3',
@@ -428,7 +438,7 @@ class Device(dtoutputs.OutputBase):
         >>> disruptive.Device.batch_update_labels(
         ...     device_ids=['<DEVICE_ID_1>']
         ...     project_id='<PROJECT_ID>',
-        ...     add_labels={'new-label': 'new-value'},
+        ...     set_labels={'new-label': 'new-value'},
         ...     remove_labels=['old-label'],
         ... )
 
@@ -449,8 +459,11 @@ class Device(dtoutputs.OutputBase):
         # Construct URL.
         url = '/projects/{}/devices:batchUpdate'.format(project_id)
 
-        # Sent POST request, but return nothing.
-        dtrequests.DTRequest.post(url, body=body, **kwargs)
+        # Sent POST request.
+        response = dtrequests.DTRequest.post(url, body=body, **kwargs)
+
+        # Return any batchErrors found in response.
+        return [LabelUpdateError(err) for err in response['batchErrors']]
 
 
 class Reported(dtoutputs.OutputBase):
