@@ -64,19 +64,15 @@ class Role(OutputBase):
         Parameters
         ----------
         role : str
-            Name of the role.
-        auth: Auth, optional
-            Authorization object used to authenticate the REST API.
-            If provided it will be prioritized over global authentication.
-        request_timeout: int, optional
-            Seconds before giving up a request without an answer.
-        request_attempts: int, optional
-            Number of times a request is attempted before giving up.
+            :ref:`Name <role_types>` of the role.
+        **kwargs
+            Arbitrary keyword arguments.
+            See the :ref:`Configuration <configuration>` page.
 
         Returns
         -------
         role : Role
-            Object representing the specified role.
+            Object representing the specified :ref:`role <role_types>`.
 
         Examples
         --------
@@ -100,18 +96,14 @@ class Role(OutputBase):
 
         Parameters
         ----------
-        auth: Auth, optional
-            Authorization object used to authenticate the REST API.
-            If provided it will be prioritized over global authentication.
-        request_timeout: int, optional
-            Seconds before giving up a request without an answer.
-        request_attempts: int, optional
-            Number of times a request is attempted before giving up.
+        **kwargs
+            Arbitrary keyword arguments.
+            See the :ref:`Configuration <configuration>` page.
 
         Returns
         -------
         roles : list[Role]
-            List of objects each representing a role.
+            List of objects each representing a :ref:`role <role_types>`.
 
         Examples
         --------
